@@ -127,7 +127,7 @@ setMethodS3("all.equal", "AbstractCBS", function(target, current, check.attribut
 #*/###########################################################################
 setMethodS3("save", "AbstractCBS", function(this, ...) {
   saveObject(this, ...);
-}, createGeneric=FALSE)
+})
 
 
 ###########################################################################/**
@@ -179,7 +179,7 @@ setMethodS3("load", "AbstractCBS", function(static, ...) {
   }
 
   object;
-}, static=TRUE, createGeneric=FALSE)
+}, static=TRUE)
 
 
 
